package com.gic.haoban.manage.service.task;

import com.alibaba.fastjson.JSONObject;
import com.gic.binlog.base.entity.GicField;
import com.gic.binlog.base.entity.GicRecord;
import com.gic.binlog.base.entity.enums.GicRecordType;
import com.gic.commons.util.EntityUtil;
import com.gic.haoban.contacts.manage.api.enums.StatusEnum;
import com.gic.haoban.manage.api.dto.StaffClerkRelationDTO;
import com.gic.haoban.manage.service.pojo.BinlogBasePojo;
import com.gic.haoban.manage.service.pojo.ClerkSyncPojo;
import com.gic.haoban.manage.service.service.StaffClerkRelationService;
import org.apache.commons.lang3.time.DateUtils;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.listener.MessageListener;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created 2019/4/10.
 *
 * @author hua
 */
public class KafkaMessageServiceImpl implements MessageListener<String, GicRecord> {

    private final static Logger logger = LoggerFactory.getLogger(KafkaMessageServiceImpl.class);

    private  final String STORE = "tab_gic_store";

    private final  String CLERK = "tab_gic_clerk";

    @Autowired
    private StaffClerkRelationService staffClerkRelationService;


    @Override
    public void onMessage(ConsumerRecord<String, GicRecord> record) {
        logger.info("message：{}", JSONObject.toJSONString(record.value()));
        if(record.value()==null){
            logger.info("数据为空");
            return;
        }
        BinlogBasePojo pojo = binlogChange(record.value());
        logger.info("binlog数据：{}", JSONObject.toJSONString(pojo));

        if (record.value().getTableName().equals(CLERK)) {
            dealClerk((ClerkSyncPojo)pojo);
        }
    }

    private void dealClerk(ClerkSyncPojo syncPojo) {
        GicRecordType gicRecordType = GicRecordType.valueOf(syncPojo.getRecordType());
        if(gicRecordType.equals(GicRecordType.DELETE)){
            staffClerkRelationService.delBind(syncPojo.getClerkId());
        }else if (gicRecordType.equals(GicRecordType.INSERT)) {
            StaffClerkRelationDTO relationDTO = staffClerkRelationService.getOneBindCodeNoStatus(syncPojo.getEnterpriseId(), syncPojo.getClerkCode());
            if (null == relationDTO) {
                logger.info("没有关联导购，不需要新增");
                return;
            }
            //正常的时候
            if (relationDTO.getStatusFlag() != StatusEnum.DEL.getValue()) {
                staffClerkRelationService.delBind(relationDTO.getClerkId());
                relationDTO.setClerkId(syncPojo.getClerkId());
                relationDTO.setStoreId(syncPojo.getStoreId());
                staffClerkRelationService.bind(relationDTO);
            }else {//删除状态 需要判断是否近段时间有操作删除 2分组内有更新 判断是转移操作
                Date timeDiff = DateUtils.addMinutes(new Date(), -2);
                if(relationDTO.getUpdateTime().after(timeDiff)){
                    staffClerkRelationService.delBind(relationDTO.getClerkId());
                    relationDTO.setClerkId(syncPojo.getClerkId());
                    relationDTO.setStoreId(syncPojo.getStoreId());
                    staffClerkRelationService.bind(relationDTO);
                }
            }
        }else if (gicRecordType.equals(GicRecordType.UPDATE)) {
            StaffClerkRelationDTO relationDTO = new StaffClerkRelationDTO();
            relationDTO.setClerkId(syncPojo.getClerkId());
            relationDTO.setStoreId(syncPojo.getStoreId());
            relationDTO.setClerkCode(syncPojo.getClerkCode());
            staffClerkRelationService.updateByClerkId(relationDTO);
        }
    }

    private BinlogBasePojo binlogChange(GicRecord record) {
        ClerkSyncPojo pojo=new ClerkSyncPojo();
        pojo.setRecordType(record.getRecordType().value());
        if(record.getTableName().equals(CLERK)) {
            return binlogMap(record.getFieldList(),record.getRecordType(),ClerkSyncPojo.class);
        }else if (record.getTableName().equals(STORE)) {
            return binlogMap(record.getFieldList(),record.getRecordType(),ClerkSyncPojo.class);
        }else{
            return null;
        }
    }

    private BinlogBasePojo binlogMap(List<GicField> list,GicRecordType recordType,Class<? extends BinlogBasePojo> aclass) {
        Map<String,String> mid=new HashMap<>();
        for (GicField gicField : list) {
            mid.put(gicField.getName(),gicField.getValue());
        }
        BinlogBasePojo pojo = EntityUtil.changeEntityByJSON(aclass, mid);
        pojo.setRecordType(recordType.value());
        return pojo;

    }


}
