package com.gic.haoban.manage.web.controller;


import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.api.base.commons.Page;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.dto.MaterialCategoryDTO;
import com.gic.haoban.manage.api.dto.MaterialDTO;
import com.gic.haoban.manage.api.dto.StaffDTO;
import com.gic.haoban.manage.api.service.MaterialApiService;
import com.gic.haoban.manage.web.auth.AuthRequestUtil;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.vo.LoginVO;

@RestController
public class MaterialController extends WebBaseController{
	
	@Autowired
	private MaterialApiService materialApiService;
	
	/**
     * 素材分组新增
     * @return
     */
    @RequestMapping("/mateial-add-category")
    public HaobanResponse materialAddCategory(MaterialCategoryDTO materialCategoryDTO) {
    	LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
    	String wxEnterpriseId = login.getWxEnterpriseId();
    	materialCategoryDTO.setWxEnterpriseId(wxEnterpriseId);
		String categoryName  = materialCategoryDTO.getCategoryName();
		String categoryParentId = materialCategoryDTO.getCategoryParentId();
		if(StringUtils.isAnyBlank(categoryParentId,categoryName)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		boolean flag = materialApiService.hasCategoryNameExsit(categoryName,categoryParentId,null);
		if(flag){
			return resultResponse(HaoBanErrCode.ERR_10015);
		}
		materialApiService.insertCategory(materialCategoryDTO);
    	return resultResponse(HaoBanErrCode.ERR_1);
    }
	
	/**
     * 素材分组查询
     * @return
     */
    @RequestMapping("/category-list")
    public HaobanResponse categoryList(String wxEnterpriseId) {
		List<MaterialCategoryDTO> list = materialApiService.listCategory(wxEnterpriseId);
    	return resultResponse(HaoBanErrCode.ERR_1,list);
    }
	
	/**
     * 素材分组修改
     * @return
     */
    @RequestMapping("/category-edit")
    public HaobanResponse categoryEdit(MaterialCategoryDTO materialCategoryDTO) {
		String categoryName  = materialCategoryDTO.getCategoryName();
		String categoryId = materialCategoryDTO.getCategoryId();
		if(StringUtils.isAnyBlank(categoryName,categoryId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		MaterialCategoryDTO dto = materialApiService.selectMaterialCategoryById(categoryId);
		if(dto == null){
			return resultResponse(HaoBanErrCode.ERR_10016);
		}
		String categoryParentId = dto.getCategoryParentId();
		boolean flag = materialApiService.hasCategoryNameExsit(categoryName,categoryParentId,materialCategoryDTO.getCategoryId());
		if(flag){
			return resultResponse(HaoBanErrCode.ERR_10015);
		}
		materialApiService.editCategory(materialCategoryDTO);
    	return resultResponse(HaoBanErrCode.ERR_1);
    }
    
    
    /**
     * 素材分组删除
     * @return
     */
    @RequestMapping("/category-del")
    public HaobanResponse categoryDel(String categoryId) {
    	MaterialCategoryDTO dto = materialApiService.selectMaterialCategoryById(categoryId);
		if(dto == null){
			return resultResponse(HaoBanErrCode.ERR_10016);
		}
		List<MaterialCategoryDTO> categoryList = materialApiService.listByParentCategory(categoryId);
		if(categoryList != null && !categoryList.isEmpty()){
			return resultResponse(HaoBanErrCode.ERR_10017);
		}
		
		List<MaterialDTO> list = materialApiService.listMaterialByCategoryId(categoryId);
		if(list!= null && !list.isEmpty()){
			return resultResponse(HaoBanErrCode.ERR_10017);
		}
		dto.setStatusFlag(0);
		materialApiService.editCategory(dto);
    	return resultResponse(HaoBanErrCode.ERR_1);
    }
    
    /**
     * 素材新增
     * @return
     */
    @RequestMapping("/material-add")
    public HaobanResponse materialAdd(MaterialDTO materialDTO) {
    	LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
    	String wxEnterpriseId = login.getWxEnterpriseId();
    	materialDTO.setWxEnterpriseId(wxEnterpriseId);
    	
    	StaffDTO staff = login.getStaffDTO();
    	materialDTO.setStaffId(staff.getStaffId());
    	materialDTO.setStaffName(staff.getStaffName());
		String materialTitle  = materialDTO.getMaterialTitle();
		String categoryId = materialDTO.getCategoryId();
		Integer categoryType = materialDTO.getMaterialType();
		if(StringUtils.isAnyBlank(categoryId,materialTitle)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		if(categoryType == null){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		materialApiService.insertMaterial(materialDTO);
    	return resultResponse(HaoBanErrCode.ERR_1);
    }
    
    /**
     * 素材详情
     * @return
     */
    @RequestMapping("/material-detail")
    public HaobanResponse materialDetail(String materialId) {
		MaterialDTO dto = materialApiService.selectMaterialById(materialId);
    	return resultResponse(HaoBanErrCode.ERR_1,dto);
    }
    
    /**
     * 素材修改
     * @return
     */
    @RequestMapping("/material-edit")
    public HaobanResponse materialEdit(MaterialDTO materialDTO) {
    	LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
    	
    	StaffDTO staff = login.getStaffDTO();
    	materialDTO.setStaffId(staff.getStaffId());
    	materialDTO.setStaffName(staff.getStaffName());
		String materialId = materialDTO.getMaterialId();
		MaterialDTO dto = materialApiService.selectMaterialById(materialId);
		if(dto == null){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		materialApiService.editMaterial(materialDTO);
    	return resultResponse(HaoBanErrCode.ERR_1);
    }
    
    /**
     * 素材删除
     * @return
     */
    @RequestMapping("/material-del")
    public HaobanResponse materialEdit(String materialIds) {
    	if(StringUtils.isBlank(materialIds)){
    		return resultResponse(HaoBanErrCode.ERR_2);
    	}
    	String[] stringArr = materialIds.split(",");
    	for (String materialId : stringArr) {
    		MaterialDTO dto = materialApiService.selectMaterialById(materialId);
    		if(dto == null){
    			continue;
    		}
    		dto.setStatusFlag(0);
    		materialApiService.editMaterial(dto);
		}
    	return resultResponse(HaoBanErrCode.ERR_1);
    }
	
    /**
     * 素材查询
     * @return
     */
    @RequestMapping("/material-list")
    public HaobanResponse materialList(String wxEnterpriseId,String keyword,String categoryId,Integer materialType,BasePageInfo pageInfo) {
    	Page<MaterialDTO> page = materialApiService.listMaterial(wxEnterpriseId,keyword,categoryId,materialType,pageInfo);
    	return resultResponse(HaoBanErrCode.ERR_1,page);
    }
    
    /**
     * 素材批量转移
     * @return
     */
    @RequestMapping("/material-batch")
    public HaobanResponse materialBatch(String materialIds,String categoryId) {
    	String[] stringArr = materialIds.split(",");
    	for (String materialId : stringArr) {
    		MaterialDTO dto = materialApiService.selectMaterialById(materialId);
    		if(dto == null){
    			continue;
    		}
    		dto.setCategoryId(categoryId);;
    		materialApiService.editMaterial(dto);
		}
    	return resultResponse(HaoBanErrCode.ERR_1);
    }

}
